# `endaq-python`: A comprehensive, user-centric Python API for working with enDAQ data and devices

`endaq-python` is essentially a meta-package, combining several function-specific sub-packages, and providing a central repository from which to build the documentation.

This package consists of several submodules:
* `endaq.calc` ([repo](https://github.com/MideTechnology/endaq-python-calc)): A computational backend for vibration analysis.
* `endaq.cloud` ([repo](https://github.com/MideTechnology/endaq-python-cloud)): Tools for interacting with enDAQ Cloud services.
* `endaq.ide` ([repo](https://github.com/MideTechnology/endaq-python-ide)): High-level utility functions to aid in importing and inspecting enDAQ IDE recording files.
* `endaq.plot` ([repo](https://github.com/MideTechnology/endaq-python-plot)):  A package comprising a collection of plotting utilities for sensor data analysis.
<!-- * `endaq.io` ([repo](https://github.com/MideTechnology/endaq-python-io)) -->
